import * as React from 'react';
import { IgPoint } from "igniteui-react-core";
import { XamBulletGraph } from './XamBulletGraph';
import { LinearScaleOrientation } from './LinearScaleOrientation';
import { IgrFormatLinearGraphLabelEventArgs } from './igr-format-linear-graph-label-event-args';
import { IgrAlignLinearGraphLabelEventArgs } from './igr-align-linear-graph-label-event-args';
import { IgrLinearGraphRange } from './igr-linear-graph-range';
import { IgrLinearGraphRangeCollection } from './igr-linear-graph-range-collection';
import { IChartTooltipProps } from "igniteui-react-core";
import { HighlightedValueDisplayMode } from "igniteui-react-core";
/**
 * Represents a bullet graph.
*/
export declare class IgrBulletGraph extends React.Component<IIgrBulletGraphProps> {
    private _height;
    private _width;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    private _elRef;
    private _container;
    private _contentChildrenManager;
    private _updateContentChildren;
    contentRanges: IgrLinearGraphRange[];
    /**
    * The ranges actually present in the chart. Do not directly modify this array.
    * This array's contents can be modified by causing Angular to reproject the child content.
    * Or adding and removing ranges from the manual ranges collection on the ranges property.
    */
    actualRanges: IgrLinearGraphRange[];
    private _ranges;
    private _rangesAdapter;
    /**
     * A collection or manually added axes for the chart.
    */
    get ranges(): IgrLinearGraphRangeCollection;
    protected _tooltipRef(t: any): void;
    render(): React.DetailedReactHTMLElement<{
        className: string;
        ref: (div: HTMLDivElement) => void;
        children: any[];
    }, HTMLDivElement>;
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    private _renderer;
    private _getMainRef;
    constructor(props: IIgrBulletGraphProps);
    destroy(): void;
    private _wrapper;
    protected createImplementation(): XamBulletGraph;
    private _gauge;
    initializeContent(): void;
    componentWillUnmount(): void;
    private _tooltipTemplate;
    private _tooltipContent;
    set tooltipTemplate(value: React.FunctionComponent<IChartTooltipProps> | React.Component<IChartTooltipProps>);
    get tooltipTemplate(): React.FunctionComponent<IChartTooltipProps> | React.Component<IChartTooltipProps>;
    private createWrapper;
    private _defaultTooltips;
    private _ensureDefaultTooltip;
    private _onDefaultTooltipsReady;
    private _activeTooltips;
    private _activeTooltipElements;
    private _currentTooltips;
    private _uniqueTooltipId;
    private createTooltip;
    private _initialized;
    private _updateTooltipState;
    private _ensureTooltipCreated;
    protected _implementation: any;
    protected mounted: boolean;
    get nativeElement(): HTMLElement;
    /**
     * @hidden
     */
    get i(): XamBulletGraph; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrBulletGraph;
    /**
 * Gets a value indicating whether the bullet graph is currently animating.
*/
    get animating(): boolean;
    /**
     * Gets the transition progress of the animation when the control is animating.
    */
    get transitionProgress(): number;
    set transitionProgress(v: number);
    /**
     * Gets or sets the orientation of the scale.
    */
    get orientation(): LinearScaleOrientation;
    set orientation(v: LinearScaleOrientation);
    /**
     * Gets or sets the background brush for the scale.
    */
    get scaleBackgroundBrush(): string;
    set scaleBackgroundBrush(v: string);
    /**
     * Gets or sets the background outline for the scale.
    */
    get scaleBackgroundOutline(): string;
    set scaleBackgroundOutline(v: string);
    /**
     * Gets or sets the background outline thickness for the scale.
    */
    get scaleBackgroundThickness(): number;
    set scaleBackgroundThickness(v: number);
    /**
     * Gets or sets a collection of brushes to be used as the palette for bullet graph ranges.
    */
    get rangeBrushes(): string[];
    set rangeBrushes(v: string[]);
    /**
     * Gets or sets a collection of brushes to be used as the palette for bullet graph outlines.
    */
    get rangeOutlines(): string[];
    set rangeOutlines(v: string[]);
    /**
     * Gets or sets the minimum value of the scale.
    */
    get minimumValue(): number;
    set minimumValue(v: number);
    /**
     * Gets the resolved minimum value of the scale.
    */
    get actualMinimumValue(): number;
    set actualMinimumValue(v: number);
    /**
     * Gets or sets the maximum value of the scale.
    */
    get maximumValue(): number;
    set maximumValue(v: number);
    /**
     * Gets the resolved maximum value of the scale.
    */
    get actualMaximumValue(): number;
    set actualMaximumValue(v: number);
    /**
     * Gets or sets the value indicated by the target value bar.
    */
    get targetValue(): number;
    set targetValue(v: number);
    /**
     * Gets or sets the name used for the target value. The name is displayed in the default target value tooltip.
    */
    get targetValueName(): string;
    set targetValueName(v: string);
    /**
     * Gets or sets the value at which the bar ends.
    */
    get value(): number;
    set value(v: number);
    /**
     * Gets or sets the name used for actual value.
    */
    get valueName(): string;
    set valueName(v: string);
    /**
     * Gets or sets the highlight value at which to point the secondary needle of the gauge.
    */
    get highlightValue(): number;
    set highlightValue(v: number);
    /**
     * Gets the actual opacity of the primary needle while highlighting
    */
    get actualHighlightValueOpacity(): number;
    set actualHighlightValueOpacity(v: number);
    /**
     * Gets or sets the opacity of the primary needle while highlighting
    */
    get highlightValueOpacity(): number;
    set highlightValueOpacity(v: number);
    /**
     * Gets whether and how to display the highlighted value.
    */
    get actualHighlightValueDisplayMode(): HighlightedValueDisplayMode;
    set actualHighlightValueDisplayMode(v: HighlightedValueDisplayMode);
    /**
     * Gets or sets whether and how to display the highlighted value.
    */
    get highlightValueDisplayMode(): HighlightedValueDisplayMode;
    set highlightValueDisplayMode(v: HighlightedValueDisplayMode);
    /**
     * Gets or sets the position at which to start rendering the ranges, measured from the front/bottom of the control as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get rangeInnerExtent(): number;
    set rangeInnerExtent(v: number);
    /**
     * Gets or sets the position at which to stop rendering the range as a value from 0 to 1 measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get rangeOuterExtent(): number;
    set rangeOuterExtent(v: number);
    /**
     * Gets or sets the position at which to start rendering the actual value geometries, measured from the front/bottom of the bullet graph as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get valueInnerExtent(): number;
    set valueInnerExtent(v: number);
    /**
     * Gets or sets the position at which to stop rendering the actual value geometries as a value from 0 to 1 measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get valueOuterExtent(): number;
    set valueOuterExtent(v: number);
    /**
     * Gets or sets the interval to use for the scale.
    */
    get interval(): number;
    set interval(v: number);
    /**
     * A value to start adding tickmarks, added to the scale's MinimumValue.
    */
    get ticksPostInitial(): number;
    set ticksPostInitial(v: number);
    /**
     * A value to stop adding tickmarks, subtracted from the scale's MaximumValue.
    */
    get ticksPreTerminal(): number;
    set ticksPreTerminal(v: number);
    /**
     * Gets or sets the interval to use for rendering labels. This defaults to be the same interval as the tickmarks on the scale.
    */
    get labelInterval(): number;
    set labelInterval(v: number);
    /**
     * Gets or sets the position at which to put the labels as a value from 0 to 1, measured from the bottom of the scale.
     * Values further from zero than 1 can be used to hide the labels of the bullet graph.
    */
    get labelExtent(): number;
    set labelExtent(v: number);
    /**
     * A value to start adding labels, added to the scale's MinimumValue.
    */
    get labelsPostInitial(): number;
    set labelsPostInitial(v: number);
    /**
     * A value to stop adding labels, subtracted from the scale's MaximumValue.
    */
    get labelsPreTerminal(): number;
    set labelsPreTerminal(v: number);
    /**
     * Gets or sets the number of minor tickmarks to place between major tickmarks.
    */
    get minorTickCount(): number;
    set minorTickCount(v: number);
    /**
     * Gets or sets the position at which to start rendering the major tickmarks as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get tickStartExtent(): number;
    set tickStartExtent(v: number);
    /**
     * Gets or sets the position at which to stop rendering the major tickmarks as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get tickEndExtent(): number;
    set tickEndExtent(v: number);
    /**
     * Gets or sets the stroke thickness to use when rendering ticks.
    */
    get tickStrokeThickness(): number;
    set tickStrokeThickness(v: number);
    /**
     * Gets or sets the brush to use for the major tickmarks.
    */
    get tickBrush(): string;
    set tickBrush(v: string);
    /**
     * Gets or sets the brush to use for the label font.
    */
    get fontBrush(): string;
    set fontBrush(v: string);
    /**
     * Gets or sets the brush to use for the actual value element.
    */
    get valueBrush(): string;
    set valueBrush(v: string);
    /**
     * Gets or sets the brush to use for the outline of actual value element.
    */
    get valueOutline(): string;
    set valueOutline(v: string);
    /**
     * Gets or sets the stroke thickness to use when rendering single actual value element.
    */
    get valueStrokeThickness(): number;
    set valueStrokeThickness(v: number);
    /**
     * Gets or sets the position at which to start rendering the minor tickmarks as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get minorTickStartExtent(): number;
    set minorTickStartExtent(v: number);
    /**
     * Gets or sets the position at which to stop rendering the minor tickmarks as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get minorTickEndExtent(): number;
    set minorTickEndExtent(v: number);
    /**
     * Gets or sets the stroke thickness to use when rendering minor ticks.
    */
    get minorTickStrokeThickness(): number;
    set minorTickStrokeThickness(v: number);
    /**
     * Gets or sets the brush to use for the minor tickmarks.
    */
    get minorTickBrush(): string;
    set minorTickBrush(v: string);
    /**
     * Gets or sets a value indicating whether the scale is inverted.
     * When the scale is inverted the direction in which the scale values increase is right to left.
    */
    get isScaleInverted(): boolean;
    set isScaleInverted(v: boolean);
    /**
     * Gets or sets the brush to use to fill the backing of the bullet graph.
    */
    get backingBrush(): string;
    set backingBrush(v: string);
    /**
     * Gets or sets the brush to use for the outline of the backing.
    */
    get backingOutline(): string;
    set backingOutline(v: string);
    /**
     * Gets or sets the stroke thickness of the backing outline.
    */
    get backingStrokeThickness(): number;
    set backingStrokeThickness(v: number);
    /**
     * Gets or sets the inner extent of the bullet graph backing.
    */
    get backingInnerExtent(): number;
    set backingInnerExtent(v: number);
    /**
     * Gets or sets the outer extent of the bullet graph backing.
    */
    get backingOuterExtent(): number;
    set backingOuterExtent(v: number);
    /**
     * Gets or sets the position at which to start rendering the scale, measured from the front/bottom of the bullet graph as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get scaleStartExtent(): number;
    set scaleStartExtent(v: number);
    /**
     * Gets or sets the position at which to stop rendering the scale as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get scaleEndExtent(): number;
    set scaleEndExtent(v: number);
    /**
     * Gets or sets the brush to use when rendering the fill of the comparative marker.
    */
    get targetValueBrush(): string;
    set targetValueBrush(v: string);
    /**
     * Get or sets the breadth of the target value element.
    */
    get targetValueBreadth(): number;
    set targetValueBreadth(v: number);
    /**
     * Gets or sets the position at which to start rendering the target value, measured from the front/bottom of the control as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get targetValueInnerExtent(): number;
    set targetValueInnerExtent(v: number);
    /**
     * Gets or sets the position at which to start rendering the target value, measured from the front/bottom of the control as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    get targetValueOuterExtent(): number;
    set targetValueOuterExtent(v: number);
    /**
     * Gets or sets the brush to use when rendering the outline of the target value.
    */
    get targetValueOutline(): string;
    set targetValueOutline(v: string);
    /**
     * Gets or sets the stroke thickness of the outline of the target value bar.
    */
    get targetValueStrokeThickness(): number;
    set targetValueStrokeThickness(v: number);
    /**
     * Gets or sets whether the scale viewport will be merged with backing viewport.
    */
    get mergeViewports(): boolean;
    set mergeViewports(v: boolean);
    /**
     * Gets or sets the label composite format used when creating label values.
    */
    get labelFormat(): string;
    set labelFormat(v: string);
    /**
     * Gets or sets the format specifiers to use with the LabelFormat string.
    */
    get labelFormatSpecifiers(): any[];
    set labelFormatSpecifiers(v: any[]);
    /**
     * Gets or sets the number of milliseconds over which changes to the bullet graph should be animated.
    */
    get transitionDuration(): number;
    set transitionDuration(v: number);
    /**
     * Gets or sets the time in milliseconds that tooltip appearance is delayed with.
    */
    get showToolTipTimeout(): number;
    set showToolTipTimeout(v: number);
    /**
     * Gets or sets a value indicating whether tooltips are enabled.
    */
    get showToolTip(): boolean;
    set showToolTip(v: boolean);
    /**
     * Gets or sets the font.
    */
    get font(): string;
    set font(v: string);
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get pixelScalingRatio(): number;
    set pixelScalingRatio(v: number);
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get actualPixelScalingRatio(): number;
    set actualPixelScalingRatio(v: number);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Gets the value for the main scale of the bullet graph for a given point within the bounds of the bullet graph.

* @param point  * The point for which to retrieve the associated value.
*/
    getValueForPoint(point: IgPoint): number;
    /**
     * Returns visuals as a serialized string.
    
    */
    exportSerializedVisualData(): string;
    /**
     * Provide a container for the bullet graph.
    
    * @param container  * The container.
    */
    provideContainer(container: any): void;
    /**
     * Notify that the container has resized.
    
    */
    containerResized(): void;
    /**
     * Notify that the bullet graph styling has updated.
    
    */
    styleUpdated(): void;
    /**
     * Use to force the bullet graph to finish any deferred work before printing or evaluating its visual.
     * This should only be called if the visual of the bullet graph needs to be synchronously saved or evaluated.
     * Calling this method too often will hinder the performance of the bullet graph.
    
    */
    flush(): void;
    private _formatLabel;
    private _formatLabel_wrapped;
    /**
     * Event which is raised when a label of the bullet graph is formatted.
     * Function takes first argument evt and second argument ui.
     * Use ui.owner to obtain reference to the bullet graph widget.
     * Use ui.actualMinimumValue to obtain the minimum value of the bullet graph scale.
     * Use ui.actualMaximumValue to obtain the maximum value of the bullet graph scale.
     * Use ui.value to obtain the value on the the bullet graph scale associated with the label.
     * Use ui.label to obtain the string value of the label.
    */
    get formatLabel(): (s: IgrBulletGraph, e: IgrFormatLinearGraphLabelEventArgs) => void;
    set formatLabel(ev: (s: IgrBulletGraph, e: IgrFormatLinearGraphLabelEventArgs) => void);
    private _alignLabel;
    private _alignLabel_wrapped;
    /**
     * Event which is raised when a label of the bullet graph is aligned along the scale.
     * Function takes first argument evt and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of the bullet graph scale.
     * Use ui.actualMaximumValue to obtain the maximum value of the bullet graph scale.
     * Use ui.value to obtain the value on the the bullet graph scale associated with the label.
     * Use ui.label to obtain the string value of the label.
     * Use ui.width to obtain the width of the label.
     * Use ui.height to obtain the height of the label.
     * Use ui.offsetX to obtain the X offset of the label on the bullet graph scale.
     * Use ui.offsetY to obtain the Y offset of the label on the bullet graph scale.
    */
    get alignLabel(): (s: IgrBulletGraph, e: IgrAlignLinearGraphLabelEventArgs) => void;
    set alignLabel(ev: (s: IgrBulletGraph, e: IgrAlignLinearGraphLabelEventArgs) => void);
    private _actualMinimumValueChange;
    private _actualMinimumValueChange_wrapped;
    get actualMinimumValueChange(): (s: IgrBulletGraph, e: number) => void;
    set actualMinimumValueChange(ev: (s: IgrBulletGraph, e: number) => void);
    private _actualMaximumValueChange;
    private _actualMaximumValueChange_wrapped;
    get actualMaximumValueChange(): (s: IgrBulletGraph, e: number) => void;
    set actualMaximumValueChange(ev: (s: IgrBulletGraph, e: number) => void);
}
export interface IIgrBulletGraphProps {
    width?: string;
    height?: string;
    children?: React.ReactNode;
    /**
 * Gets the transition progress of the animation when the control is animating.
*/
    transitionProgress?: number | string;
    /**
     * Gets or sets the orientation of the scale.
    */
    orientation?: LinearScaleOrientation | string;
    /**
     * Gets or sets the background brush for the scale.
    */
    scaleBackgroundBrush?: string;
    /**
     * Gets or sets the background outline for the scale.
    */
    scaleBackgroundOutline?: string;
    /**
     * Gets or sets the background outline thickness for the scale.
    */
    scaleBackgroundThickness?: number | string;
    /**
     * Gets or sets a collection of brushes to be used as the palette for bullet graph ranges.
    */
    rangeBrushes?: string[] | string;
    /**
     * Gets or sets a collection of brushes to be used as the palette for bullet graph outlines.
    */
    rangeOutlines?: string[] | string;
    /**
     * Gets or sets the minimum value of the scale.
    */
    minimumValue?: number | string;
    /**
     * Gets the resolved minimum value of the scale.
    */
    actualMinimumValue?: number | string;
    /**
     * Gets or sets the maximum value of the scale.
    */
    maximumValue?: number | string;
    /**
     * Gets the resolved maximum value of the scale.
    */
    actualMaximumValue?: number | string;
    /**
     * Gets or sets the value indicated by the target value bar.
    */
    targetValue?: number | string;
    /**
     * Gets or sets the name used for the target value. The name is displayed in the default target value tooltip.
    */
    targetValueName?: string;
    /**
     * Gets or sets the value at which the bar ends.
    */
    value?: number | string;
    /**
     * Gets or sets the name used for actual value.
    */
    valueName?: string;
    /**
     * Gets or sets the highlight value at which to point the secondary needle of the gauge.
    */
    highlightValue?: number | string;
    /**
     * Gets the actual opacity of the primary needle while highlighting
    */
    actualHighlightValueOpacity?: number | string;
    /**
     * Gets or sets the opacity of the primary needle while highlighting
    */
    highlightValueOpacity?: number | string;
    /**
     * Gets whether and how to display the highlighted value.
    */
    actualHighlightValueDisplayMode?: HighlightedValueDisplayMode | string;
    /**
     * Gets or sets whether and how to display the highlighted value.
    */
    highlightValueDisplayMode?: HighlightedValueDisplayMode | string;
    /**
     * Gets or sets the position at which to start rendering the ranges, measured from the front/bottom of the control as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    rangeInnerExtent?: number | string;
    /**
     * Gets or sets the position at which to stop rendering the range as a value from 0 to 1 measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    rangeOuterExtent?: number | string;
    /**
     * Gets or sets the position at which to start rendering the actual value geometries, measured from the front/bottom of the bullet graph as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    valueInnerExtent?: number | string;
    /**
     * Gets or sets the position at which to stop rendering the actual value geometries as a value from 0 to 1 measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    valueOuterExtent?: number | string;
    /**
     * Gets or sets the interval to use for the scale.
    */
    interval?: number | string;
    /**
     * A value to start adding tickmarks, added to the scale's MinimumValue.
    */
    ticksPostInitial?: number | string;
    /**
     * A value to stop adding tickmarks, subtracted from the scale's MaximumValue.
    */
    ticksPreTerminal?: number | string;
    /**
     * Gets or sets the interval to use for rendering labels. This defaults to be the same interval as the tickmarks on the scale.
    */
    labelInterval?: number | string;
    /**
     * Gets or sets the position at which to put the labels as a value from 0 to 1, measured from the bottom of the scale.
     * Values further from zero than 1 can be used to hide the labels of the bullet graph.
    */
    labelExtent?: number | string;
    /**
     * A value to start adding labels, added to the scale's MinimumValue.
    */
    labelsPostInitial?: number | string;
    /**
     * A value to stop adding labels, subtracted from the scale's MaximumValue.
    */
    labelsPreTerminal?: number | string;
    /**
     * Gets or sets the number of minor tickmarks to place between major tickmarks.
    */
    minorTickCount?: number | string;
    /**
     * Gets or sets the position at which to start rendering the major tickmarks as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    tickStartExtent?: number | string;
    /**
     * Gets or sets the position at which to stop rendering the major tickmarks as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    tickEndExtent?: number | string;
    /**
     * Gets or sets the stroke thickness to use when rendering ticks.
    */
    tickStrokeThickness?: number | string;
    /**
     * Gets or sets the brush to use for the major tickmarks.
    */
    tickBrush?: string;
    /**
     * Gets or sets the brush to use for the label font.
    */
    fontBrush?: string;
    /**
     * Gets or sets the brush to use for the actual value element.
    */
    valueBrush?: string;
    /**
     * Gets or sets the brush to use for the outline of actual value element.
    */
    valueOutline?: string;
    /**
     * Gets or sets the stroke thickness to use when rendering single actual value element.
    */
    valueStrokeThickness?: number | string;
    /**
     * Gets or sets the position at which to start rendering the minor tickmarks as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    minorTickStartExtent?: number | string;
    /**
     * Gets or sets the position at which to stop rendering the minor tickmarks as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    minorTickEndExtent?: number | string;
    /**
     * Gets or sets the stroke thickness to use when rendering minor ticks.
    */
    minorTickStrokeThickness?: number | string;
    /**
     * Gets or sets the brush to use for the minor tickmarks.
    */
    minorTickBrush?: string;
    /**
     * Gets or sets a value indicating whether the scale is inverted.
     * When the scale is inverted the direction in which the scale values increase is right to left.
    */
    isScaleInverted?: boolean | string;
    /**
     * Gets or sets the brush to use to fill the backing of the bullet graph.
    */
    backingBrush?: string;
    /**
     * Gets or sets the brush to use for the outline of the backing.
    */
    backingOutline?: string;
    /**
     * Gets or sets the stroke thickness of the backing outline.
    */
    backingStrokeThickness?: number | string;
    /**
     * Gets or sets the inner extent of the bullet graph backing.
    */
    backingInnerExtent?: number | string;
    /**
     * Gets or sets the outer extent of the bullet graph backing.
    */
    backingOuterExtent?: number | string;
    /**
     * Gets or sets the position at which to start rendering the scale, measured from the front/bottom of the bullet graph as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    scaleStartExtent?: number | string;
    /**
     * Gets or sets the position at which to stop rendering the scale as a value from 0 to 1, measured from the front/bottom of the bullet graph.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    scaleEndExtent?: number | string;
    /**
     * Gets or sets the brush to use when rendering the fill of the comparative marker.
    */
    targetValueBrush?: string;
    /**
     * Get or sets the breadth of the target value element.
    */
    targetValueBreadth?: number | string;
    /**
     * Gets or sets the position at which to start rendering the target value, measured from the front/bottom of the control as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    targetValueInnerExtent?: number | string;
    /**
     * Gets or sets the position at which to start rendering the target value, measured from the front/bottom of the control as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal size of the bullet graph.
    */
    targetValueOuterExtent?: number | string;
    /**
     * Gets or sets the brush to use when rendering the outline of the target value.
    */
    targetValueOutline?: string;
    /**
     * Gets or sets the stroke thickness of the outline of the target value bar.
    */
    targetValueStrokeThickness?: number | string;
    /**
     * Gets or sets whether the scale viewport will be merged with backing viewport.
    */
    mergeViewports?: boolean | string;
    /**
     * Gets or sets the label composite format used when creating label values.
    */
    labelFormat?: string;
    /**
     * Gets or sets the format specifiers to use with the LabelFormat string.
    */
    labelFormatSpecifiers?: any[];
    /**
     * Gets or sets the number of milliseconds over which changes to the bullet graph should be animated.
    */
    transitionDuration?: number | string;
    /**
     * Gets or sets the time in milliseconds that tooltip appearance is delayed with.
    */
    showToolTipTimeout?: number | string;
    /**
     * Gets or sets a value indicating whether tooltips are enabled.
    */
    showToolTip?: boolean | string;
    /**
     * Gets or sets the font.
    */
    font?: string;
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    pixelScalingRatio?: number | string;
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    actualPixelScalingRatio?: number | string;
    /**
 * Event which is raised when a label of the bullet graph is formatted.
 * Function takes first argument evt and second argument ui.
 * Use ui.owner to obtain reference to the bullet graph widget.
 * Use ui.actualMinimumValue to obtain the minimum value of the bullet graph scale.
 * Use ui.actualMaximumValue to obtain the maximum value of the bullet graph scale.
 * Use ui.value to obtain the value on the the bullet graph scale associated with the label.
 * Use ui.label to obtain the string value of the label.
*/
    formatLabel?: (s: IgrBulletGraph, e: IgrFormatLinearGraphLabelEventArgs) => void;
    /**
     * Event which is raised when a label of the bullet graph is aligned along the scale.
     * Function takes first argument evt and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of the bullet graph scale.
     * Use ui.actualMaximumValue to obtain the maximum value of the bullet graph scale.
     * Use ui.value to obtain the value on the the bullet graph scale associated with the label.
     * Use ui.label to obtain the string value of the label.
     * Use ui.width to obtain the width of the label.
     * Use ui.height to obtain the height of the label.
     * Use ui.offsetX to obtain the X offset of the label on the bullet graph scale.
     * Use ui.offsetY to obtain the Y offset of the label on the bullet graph scale.
    */
    alignLabel?: (s: IgrBulletGraph, e: IgrAlignLinearGraphLabelEventArgs) => void;
}
