import * as React from 'react';
import { XamLinearGraphRange } from "./XamLinearGraphRange";
export declare class IgrLinearGraphRange extends React.Component<IIgrLinearGraphRangeProps> {
    protected _implementation: any;
    get i(): XamLinearGraphRange;
    private onImplementationCreated;
    constructor(props: IIgrLinearGraphRangeProps);
    render(): any;
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    get rangeInternal(): XamLinearGraphRange;
    protected createImplementation(): XamLinearGraphRange;
    ngOnInit(): void;
    private _renderer;
    private _provideRenderer;
    static _createFromInternal(internal: any): IgrLinearGraphRange;
    /**
 * Gets or sets the name of the range.
*/
    get name(): string;
    set name(v: string);
    /**
     * Gets or sets the brush to use to fill the range.
    */
    get brush(): string;
    set brush(v: string);
    /**
     * Gets or sets the outline to use when rendering the range.
    */
    get outline(): string;
    set outline(v: string);
    /**
     * Gets or sets the value at which the range starts along the scale.
    */
    get startValue(): number;
    set startValue(v: number);
    /**
     * Gets or sets the value at which the range ends along the scale.
    */
    get endValue(): number;
    set endValue(v: number);
    /**
     * Gets or sets the distance measured from the front/bottom of the bullet graph (from 0 to 1) at which to start rendering the inner edge of the range.
     * Values further from zero than 1 can be used to make this extend further than the normal width/height of the bullet graph.
    */
    get innerStartExtent(): number;
    set innerStartExtent(v: number);
    /**
     * Gets or sets the distance measured from the front/bottom of the bullet graph (from 0 to 1) at which to end rendering the inner edge of the range.
     * Values further from zero than 1 can be used to make this extend further than the normal width/height of the bullet graph.
    */
    get innerEndExtent(): number;
    set innerEndExtent(v: number);
    /**
     * Gets or sets the distance measured from the front/bottom of the bullet graph (from 0 to 1) at which to start rendering the outer edge of the range.
     * Values further from zero than 1 can be used to make this extend further than the normal width/height of the bullet graph.
    */
    get outerStartExtent(): number;
    set outerStartExtent(v: number);
    /**
     * Gets or sets the distance measured from the front/bottom of the bullet graph (from 0 to 1) at which to end rendering the outer edge of the range.
     * Values further from zero than 1 can be used to make this extend further than the normal width/height of the bullet graph.
    */
    get outerEndExtent(): number;
    set outerEndExtent(v: number);
    /**
     * Gets or sets the stroke thickness to use when rendering this range's outline.
    */
    get strokeThickness(): number;
    set strokeThickness(v: number);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
}
export interface IIgrLinearGraphRangeProps {
    width?: string;
    height?: string;
    children?: React.ReactNode;
    /**
 * Gets or sets the name of the range.
*/
    name?: string;
    /**
     * Gets or sets the brush to use to fill the range.
    */
    brush?: string;
    /**
     * Gets or sets the outline to use when rendering the range.
    */
    outline?: string;
    /**
     * Gets or sets the value at which the range starts along the scale.
    */
    startValue?: number | string;
    /**
     * Gets or sets the value at which the range ends along the scale.
    */
    endValue?: number | string;
    /**
     * Gets or sets the distance measured from the front/bottom of the bullet graph (from 0 to 1) at which to start rendering the inner edge of the range.
     * Values further from zero than 1 can be used to make this extend further than the normal width/height of the bullet graph.
    */
    innerStartExtent?: number | string;
    /**
     * Gets or sets the distance measured from the front/bottom of the bullet graph (from 0 to 1) at which to end rendering the inner edge of the range.
     * Values further from zero than 1 can be used to make this extend further than the normal width/height of the bullet graph.
    */
    innerEndExtent?: number | string;
    /**
     * Gets or sets the distance measured from the front/bottom of the bullet graph (from 0 to 1) at which to start rendering the outer edge of the range.
     * Values further from zero than 1 can be used to make this extend further than the normal width/height of the bullet graph.
    */
    outerStartExtent?: number | string;
    /**
     * Gets or sets the distance measured from the front/bottom of the bullet graph (from 0 to 1) at which to end rendering the outer edge of the range.
     * Values further from zero than 1 can be used to make this extend further than the normal width/height of the bullet graph.
    */
    outerEndExtent?: number | string;
    /**
     * Gets or sets the stroke thickness to use when rendering this range's outline.
    */
    strokeThickness?: number | string;
}
