import * as React from 'react';
import { IgPoint } from "igniteui-react-core";
import { XamRadialGauge } from './XamRadialGauge';
import { SweepDirection } from "igniteui-react-core";
import { RadialGaugeNeedleShape } from './RadialGaugeNeedleShape';
import { RadialGaugePivotShape } from './RadialGaugePivotShape';
import { RadialGaugeScaleOversweepShape } from './RadialGaugeScaleOversweepShape';
import { RadialGaugeBackingShape } from './RadialGaugeBackingShape';
import { RadialGaugeDuplicateLabelOmissionStrategy } from './RadialGaugeDuplicateLabelOmissionStrategy';
import { IgrFormatRadialGaugeLabelEventArgs } from './igr-format-radial-gauge-label-event-args';
import { IgrAlignRadialGaugeLabelEventArgs } from './igr-align-radial-gauge-label-event-args';
import { IgrRadialGaugeRange } from './igr-radial-gauge-range';
import { IgrRadialGaugeRangeCollection } from './igr-radial-gauge-range-collection';
import { IgrDoubleValueChangedEventArgs } from "igniteui-react-core";
import { HighlightedValueDisplayMode } from "igniteui-react-core";
export declare class IgrRadialGauge extends React.Component<IIgrRadialGaugeProps> {
    private _height;
    private _width;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    private _elRef;
    private _container;
    private _contentChildrenManager;
    private _updateContentChildren;
    contentRanges: IgrRadialGaugeRange[];
    /**
    * The ranges actually present in the chart. Do not directly modify this array.
    * This array's contents can be modified by causing Angular to reproject the child content.
    * Or adding and removing ranges from the manual ranges collection on the ranges property.
    */
    actualRanges: IgrRadialGaugeRange[];
    private _ranges;
    private _rangesAdapter;
    /**
     * A collection or manually added axes for the chart.
    */
    get ranges(): IgrRadialGaugeRangeCollection;
    render(): React.DetailedReactHTMLElement<{
        className: string;
        ref: (div: HTMLDivElement) => void;
        children: any[];
    }, HTMLDivElement>;
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    private _renderer;
    private _getMainRef;
    constructor(props: IIgrRadialGaugeProps);
    destroy(): void;
    private _wrapper;
    protected createImplementation(): XamRadialGauge;
    private _gauge;
    initializeContent(): void;
    componentWillUnmount(): void;
    protected initializeProperties(): void;
    protected _implementation: any;
    protected mounted: boolean;
    get nativeElement(): HTMLElement;
    /**
     * @hidden
     */
    get i(): XamRadialGauge; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrRadialGauge;
    /**
 * Gets or sets a collection of brushes to be used as the palette for gauge ranges.
*/
    get rangeBrushes(): string[];
    set rangeBrushes(v: string[]);
    /**
     * Gets or sets a collection of brushes to be used as the palette for gauge outlines.
    */
    get rangeOutlines(): string[];
    set rangeOutlines(v: string[]);
    /**
     * Gets or sets the minimum value of the scale.
    */
    get minimumValue(): number;
    set minimumValue(v: number);
    /**
     * Gets the resolved minimum value of the scale.
    */
    get actualMinimumValue(): number;
    set actualMinimumValue(v: number);
    /**
     * Gets or sets the maximum value of the scale.
    */
    get maximumValue(): number;
    set maximumValue(v: number);
    /**
     * Gets the resolved maximum value of the scale.
    */
    get actualMaximumValue(): number;
    set actualMaximumValue(v: number);
    /**
     * Gets or sets the interval to use for the scale.
    */
    get interval(): number;
    set interval(v: number);
    /**
     * Gets or sets the x position of the center of the gauge with the value ranging from 0 to 1.
    */
    get centerX(): number;
    set centerX(v: number);
    /**
     * Gets or sets the y position of the center of the gauge with the value ranging from 0 to 1.
    */
    get centerY(): number;
    set centerY(v: number);
    /**
     * Gets or sets the value at which to point the needle of the gauge.
    */
    get value(): number;
    set value(v: number);
    /**
     * Gets or sets the highlight value at which to point the secondary needle of the gauge.
    */
    get highlightValue(): number;
    set highlightValue(v: number);
    /**
     * Gets the actual opacity of the primary needle while highlighting
    */
    get actualHighlightValueOpacity(): number;
    set actualHighlightValueOpacity(v: number);
    /**
     * Gets or sets the opacity of the primary needle while highlighting
    */
    get highlightValueOpacity(): number;
    set highlightValueOpacity(v: number);
    /**
     * Gets whether and how to display the highlighted value.
    */
    get actualHighlightValueDisplayMode(): HighlightedValueDisplayMode;
    set actualHighlightValueDisplayMode(v: HighlightedValueDisplayMode);
    /**
     * Gets or sets whether and how to display the highlighted value.
    */
    get highlightValueDisplayMode(): HighlightedValueDisplayMode;
    set highlightValueDisplayMode(v: HighlightedValueDisplayMode);
    /**
     * Gets or sets the start angle for the scale in degrees.
    */
    get scaleStartAngle(): number;
    set scaleStartAngle(v: number);
    /**
     * Gets or sets the end angle for the scale in degrees.
    */
    get scaleEndAngle(): number;
    set scaleEndAngle(v: number);
    /**
     * Gets or sets the direction in which the scale sweeps around the center from the start angle to end angle.
    */
    get scaleSweepDirection(): SweepDirection;
    set scaleSweepDirection(v: SweepDirection);
    /**
     * Gets or sets the number of milliseconds over which changes to the gauge should be animated.
    */
    get transitionDuration(): number;
    set transitionDuration(v: number);
    /**
     * Gets or sets the brush to use when rendering the fill of the needle.
    */
    get needleBrush(): string;
    set needleBrush(v: string);
    /**
     * Gets or sets the brush to use when rendering the outline of the needle.
    */
    get needleOutline(): string;
    set needleOutline(v: string);
    /**
     * Gets or sets the extent (from -1 to 1) at which to start rendering the needle, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get needleStartExtent(): number;
    set needleStartExtent(v: number);
    /**
     * Gets or sets the extent (from -1 to 1) at which to end rendering the needle, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get needleEndExtent(): number;
    set needleEndExtent(v: number);
    /**
     * Gets or sets the shape to use when rendering the needle from a number of options.
    */
    get needleShape(): RadialGaugeNeedleShape;
    set needleShape(v: RadialGaugeNeedleShape);
    /**
     * Gets or sets the width of the needle at its point using a value from (0 to 1). Note: Only some needle shapes respect this property.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get needleStartWidthRatio(): number;
    set needleStartWidthRatio(v: number);
    /**
     * Gets or sets the width of the needle at its point using a value from (0 to 1). Note: Only some needle shapes respect this property.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get needleEndWidthRatio(): number;
    set needleEndWidthRatio(v: number);
    /**
     * Gets or sets the width of the needle at its feature which is closest to the base (e.g. a bulb) with a value from 0 to 1. Note: Only some needle shapes respect this property, namely: NeedleWithBulb, RectangleWithBulb, TrapezoidWithBulb, and TriangleWithBulb.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get needleBaseFeatureWidthRatio(): number;
    set needleBaseFeatureWidthRatio(v: number);
    /**
     * Gets or sets the extent of the feature which is closest to the base (e.g. a bulb) with a value from -1 to 1. Note: Only some needle shapes respect this property, namely: NeedleWithBulb, RectangleWithBulb, TrapezoidWithBulb, and TriangleWithBulb.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get needleBaseFeatureExtent(): number;
    set needleBaseFeatureExtent(v: number);
    /**
     * Gets or sets the width of the needle at its feature which is closest to the point (e.g. the tapering point of a needle) with a value from 0 to 1. Note: Only some needle shapes respect this property.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get needlePointFeatureWidthRatio(): number;
    set needlePointFeatureWidthRatio(v: number);
    /**
     * Gets or sets the extent of the feature which is closest to the point (e.g. the tapering point of a needle) with a value from -1 to 1. Note: Only some needle shapes respect this property.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get needlePointFeatureExtent(): number;
    set needlePointFeatureExtent(v: number);
    /**
     * Gets or sets the width of the cap of the needle with a value from 0 to 1. Note: Will only take effect if you have a cap set on the needle.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get needlePivotWidthRatio(): number;
    set needlePivotWidthRatio(v: number);
    /**
     * Gets or sets the width of the inner cutout section of the needle cap with a value from 0 to 1. Note: Will only take effect if you have a cap set on the needle that has a cutout section.
    */
    get needlePivotInnerWidthRatio(): number;
    set needlePivotInnerWidthRatio(v: number);
    /**
     * Gets or sets the shape to use for the needle cap.
    */
    get needlePivotShape(): RadialGaugePivotShape;
    set needlePivotShape(v: RadialGaugePivotShape);
    /**
     * Gets or sets the position at which to start rendering the scale, measured from the center of the gauge as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get scaleStartExtent(): number;
    set scaleStartExtent(v: number);
    /**
     * Gets or sets the brush to use for filling the needle cap. Note: this only applies to certain cap shapes.
    */
    get needlePivotBrush(): string;
    set needlePivotBrush(v: string);
    /**
     * Gets or sets the brush to use for the outlines of the needle cap.
    */
    get needlePivotOutline(): string;
    set needlePivotOutline(v: string);
    /**
     * Gets or sets the stroke thickness of the needle outline.
    */
    get needleStrokeThickness(): number;
    set needleStrokeThickness(v: number);
    /**
     * Gets or sets the stroke thickness to use for the outline of the needle cap.
    */
    get needlePivotStrokeThickness(): number;
    set needlePivotStrokeThickness(v: number);
    /**
     * Gets or sets the position at which to stop rendering the scale as a value from 0 to 1 measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get scaleEndExtent(): number;
    set scaleEndExtent(v: number);
    /**
     * Gets or sets the position at which to put the labels as a value from 0 to 1, measured form the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get labelExtent(): number;
    set labelExtent(v: number);
    /**
     * Gets or sets the interval to use for rendering labels. This defaults to be the same interval as the tickmarks on the scale.
    */
    get labelInterval(): number;
    set labelInterval(v: number);
    /**
     * Gets or sets the position at which to start rendering the major tickmarks as a value from 0 to 1, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get tickStartExtent(): number;
    set tickStartExtent(v: number);
    /**
     * Gets or sets the position at which to stop rendering the major tickmarks as a value from 0 to 1, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get tickEndExtent(): number;
    set tickEndExtent(v: number);
    /**
     * Gets or sets the stroke thickness to use when rendering ticks.
    */
    get tickStrokeThickness(): number;
    set tickStrokeThickness(v: number);
    /**
     * Gets or sets the brush to use for the major tickmarks.
    */
    get tickBrush(): string;
    set tickBrush(v: string);
    /**
     * Gets or sets the brush to use for the label font.
    */
    get fontBrush(): string;
    set fontBrush(v: string);
    /**
     * Gets or sets the position at which to start rendering the minor tickmarks as a value from 0 to 1, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get minorTickStartExtent(): number;
    set minorTickStartExtent(v: number);
    /**
     * Gets or sets the position at which to stop rendering the minor tickmarks as a value from 0 to 1, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    get minorTickEndExtent(): number;
    set minorTickEndExtent(v: number);
    /**
     * Gets or sets the stroke thickness to use when rendering minor ticks.
    */
    get minorTickStrokeThickness(): number;
    set minorTickStrokeThickness(v: number);
    /**
     * Gets or sets the brush to use for the minor tickmarks.
    */
    get minorTickBrush(): string;
    set minorTickBrush(v: string);
    /**
     * Gets or sets the number of minor tickmarks to place between major tickmarks.
    */
    get minorTickCount(): number;
    set minorTickCount(v: number);
    /**
     * Gets or sets the brush to use to fill the background of the scale.
    */
    get scaleBrush(): string;
    set scaleBrush(v: string);
    /**
     * Gets or sets the brush to use to fill the backing of the gauge.
    */
    get backingBrush(): string;
    set backingBrush(v: string);
    /**
     * Gets or sets the brush to use for the outline of the backing.
    */
    get backingOutline(): string;
    set backingOutline(v: string);
    /**
     * Gets or sets the stroke thickness of the backing outline.
    */
    get backingStrokeThickness(): number;
    set backingStrokeThickness(v: number);
    /**
     * Gets or sets the outer extent of the gauge backing.
    */
    get backingOuterExtent(): number;
    set backingOuterExtent(v: number);
    /**
     * Gets or sets the over sweep angle to apply to the backing if it is displaying fitted (in degrees). Must be greater or equal to 0.
    */
    get backingOversweep(): number;
    set backingOversweep(v: number);
    /**
     * Gets or sets the extra degrees of sweep to apply to the scale background. Must be greater or equal to 0.
    */
    get scaleOversweep(): number;
    set scaleOversweep(v: number);
    /**
     * Gets or sets the oversweep shape to use for the excess fill area for the scale.
    */
    get scaleOversweepShape(): RadialGaugeScaleOversweepShape;
    set scaleOversweepShape(v: RadialGaugeScaleOversweepShape);
    /**
     * Gets or sets the corner rounding radius to use for the fitted scale backings.
    */
    get backingCornerRadius(): number;
    set backingCornerRadius(v: number);
    /**
     * Gets or sets the inner extent of the gauge backing.
    */
    get backingInnerExtent(): number;
    set backingInnerExtent(v: number);
    /**
     * Gets or sets the type of shape to use for the backing of the gauge.
    */
    get backingShape(): RadialGaugeBackingShape;
    set backingShape(v: RadialGaugeBackingShape);
    /**
     * Gets or sets the multiplying factor to apply to the normal radius of the gauge.
     * The radius of the gauge is defined by the minimum of the width and height of the control divided by 2.0.
     * This introduces a multiplicative factor to that value.
    */
    get radiusMultiplier(): number;
    set radiusMultiplier(v: number);
    /**
     * Gets or sets the strategy to use for omitting labels if the first and last label have the same value.
    */
    get duplicateLabelOmissionStrategy(): RadialGaugeDuplicateLabelOmissionStrategy;
    set duplicateLabelOmissionStrategy(v: RadialGaugeDuplicateLabelOmissionStrategy);
    /**
     * Gets or sets whether needle dragging is enabled or not.
    */
    get isNeedleDraggingEnabled(): boolean;
    set isNeedleDraggingEnabled(v: boolean);
    /**
     * Gets or sets whether the needle is constrained within the minimum and maximum value range during dragging.
    */
    get isNeedleDraggingConstrained(): boolean;
    set isNeedleDraggingConstrained(v: boolean);
    /**
     * Gets or sets whether needle dragging is enabled or not.
    */
    get isHighlightNeedleDraggingEnabled(): boolean;
    set isHighlightNeedleDraggingEnabled(v: boolean);
    /**
     * Gets or sets whether the needle is constrained within the minimum and maximum value range during dragging.
    */
    get isHighlightNeedleDraggingConstrained(): boolean;
    set isHighlightNeedleDraggingConstrained(v: boolean);
    /**
     * Gets or sets the font.
    */
    get font(): string;
    set font(v: string);
    /**
     * Gets or sets the label composite format used when creating label values.
    */
    get labelFormat(): string;
    set labelFormat(v: string);
    /**
     * Gets or sets the format specifiers to use with the LabelFormat string.
    */
    get labelFormatSpecifiers(): any[];
    set labelFormatSpecifiers(v: any[]);
    /**
     * Gets a value indicating whether the radial gauge is currently animating.
    */
    get animating(): boolean;
    /**
     * Gets the transition progress of the animation when the control is animating.
    */
    get transitionProgress(): number;
    set transitionProgress(v: number);
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get pixelScalingRatio(): number;
    set pixelScalingRatio(v: number);
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get actualPixelScalingRatio(): number;
    set actualPixelScalingRatio(v: number);
    /**
     * Gets the optical scaling ratio calculated by dividing minimum gauge size by value of OpticalScalingSize property.
    */
    get opticalScalingRatio(): number;
    set opticalScalingRatio(v: number);
    /**
     * Gets or sets the title uses optical scaling when the gauge is resized.
    */
    get opticalScalingEnabled(): boolean;
    set opticalScalingEnabled(v: boolean);
    /**
     * Gets or sets the size at which labels have 100% optical scaling, e.g. labels will have larger fonts when gauge's size is larger
     * - labels will have 200% larger fonts when gauge's size is 1000 and this property is set to 500
     * - labels will have 50% smaller fonts when gauge's size is 250 and this property is set to 500
    */
    get opticalScalingSize(): number;
    set opticalScalingSize(v: number);
    /**
     * Gets or sets the text displayed in the title of the gauge.
    */
    get titleText(): string;
    set titleText(v: string);
    /**
     * Gets or sets the text displayed in the subtitle of the gauge.
    */
    get subtitleText(): string;
    set subtitleText(v: string);
    /**
     * Gets or sets the angle for the inner label in degrees.
    */
    get titleAngle(): number;
    set titleAngle(v: number);
    /**
     * Gets or sets the angle for the inner label in degrees.
    */
    get subtitleAngle(): number;
    set subtitleAngle(v: number);
    /**
     * Gets or sets the angle for the inner label in degrees.
    */
    get titleExtent(): number;
    set titleExtent(v: number);
    /**
     * Gets or sets the angle for the inner label in degrees.
    */
    get subtitleExtent(): number;
    set subtitleExtent(v: number);
    /**
     * Gets or sets the brush to use for rendering inner unit text
    */
    get titleBrush(): string;
    set titleBrush(v: string);
    /**
     * Gets or sets the brush to use for rendering inner unit text
    */
    get subtitleBrush(): string;
    set subtitleBrush(v: string);
    /**
     * Gets or sets the title show values of the gauge.
    */
    get titleDisplaysValue(): boolean;
    set titleDisplaysValue(v: boolean);
    /**
     * Gets or sets the subtitle show values of the gauge.
    */
    get subtitleDisplaysValue(): boolean;
    set subtitleDisplaysValue(v: boolean);
    /**
     * Gets or sets whether or not the title should snap angle position to needle pivot (opposite of needle pointer).
    */
    get titleSnapsToNeedlePivot(): boolean;
    set titleSnapsToNeedlePivot(v: boolean);
    /**
     * Gets or sets whether or not the subtitle should snap angle position to needle pivot (opposite of needle pointer).
    */
    get subtitleSnapsToNeedlePivot(): boolean;
    set subtitleSnapsToNeedlePivot(v: boolean);
    /**
     * Gets or sets the subtitle format used when creating subtitle label.
    */
    get subtitleFormat(): string;
    set subtitleFormat(v: string);
    /**
     * Gets or sets the format specifiers to use with the SubtitleFormat string.
    */
    get subtitleFormatSpecifiers(): any[];
    set subtitleFormatSpecifiers(v: any[]);
    /**
     * Gets or sets the title format used when creating title label.
    */
    get titleFormat(): string;
    set titleFormat(v: string);
    /**
     * Gets or sets the format specifiers to use with the TitleFormat string.
    */
    get titleFormatSpecifiers(): any[];
    set titleFormatSpecifiers(v: any[]);
    /**
     * Gets or sets the text displayed for the highlight label of the gauge.
    */
    get highlightLabelText(): string;
    set highlightLabelText(v: string);
    /**
     * Gets or sets the angle for the highlight label in degrees.
    */
    get highlightLabelAngle(): number;
    set highlightLabelAngle(v: number);
    /**
     * Gets or sets the angle for the highlight label in degrees.
    */
    get highlightLabelExtent(): number;
    set highlightLabelExtent(v: number);
    /**
     * Gets or sets the brush to use for rendering highlight text
    */
    get highlightLabelBrush(): string;
    set highlightLabelBrush(v: string);
    /**
     * Gets or sets the highlight label shows values of the gauge.
    */
    get highlightLabelDisplaysValue(): boolean;
    set highlightLabelDisplaysValue(v: boolean);
    /**
     * Gets or sets whether or not the highlight label should snap angle position to needle pivot (opposite of needle pointer).
    */
    get highlightLabelSnapsToNeedlePivot(): boolean;
    set highlightLabelSnapsToNeedlePivot(v: boolean);
    /**
     * Gets or sets the format used when creating highlight label.
    */
    get highlightLabelFormat(): string;
    set highlightLabelFormat(v: string);
    /**
     * Gets or sets the format specifiers to use with the HighlightLabelFormat string.
    */
    get highlightLabelFormatSpecifiers(): any[];
    set highlightLabelFormatSpecifiers(v: any[]);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get highlightLabelTextStyle(): string;
    set highlightLabelTextStyle(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get subtitleTextStyle(): string;
    set subtitleTextStyle(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get titleTextStyle(): string;
    set titleTextStyle(v: string);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Scales a value on the gauge's main scale to an angle around the center point of the gauge, in radians.

* @param value  * The value to scale.
*/
    scaleValue(value: number): number;
    /**
     * Unscales a value from an angle in radians to the represented value along the main scale of the gauge.
    
    * @param angle  * The angle in radians to unscale to a value.
    */
    unscaleValue(angle: number): number;
    /**
     * Gets the value for the main scale of the gauge for a given point within the bounds of the gauge.
    
    * @param point  * The point for which to retrieve the associated value.
    */
    getValueForPoint(point: IgPoint): number;
    getPointForValue(value: number, extent: number): IgPoint;
    styleUpdated(): void;
    needleContainsPoint(point: IgPoint, isFinger: boolean): boolean;
    highlightNeedleContainsPoint(point: IgPoint, isFinger: boolean): boolean;
    /**
     * Called by the UI framework to provide a UI container for rendering this control.
    
    * @param container  * The UI container element.
    */
    provideContainer(container: any): void;
    containerResized(): void;
    /**
     * Use to force the radial gauge to finish any deferred work before printing or evaluating its visual.
     * This should only be called if the visual of the radial gauge needs to be synchronously saved or evaluated.
     * Calling this method too often will hinder the performance of the radial gauge.
    
    */
    flush(): void;
    /**
     * Returns visuals as a serialized string.
    
    */
    exportSerializedVisualData(): string;
    private _alignTitle;
    private _alignTitle_wrapped;
    /**
     * Event which is raised when a title of the gauge is aligned and styled.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the label.
     * Use ui.label to obtain the string value of the label.
    */
    get alignTitle(): (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void;
    set alignTitle(ev: (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void);
    private _alignSubtitle;
    private _alignSubtitle_wrapped;
    /**
     * Event which is raised when a subtitle of the gauge is aligned and styled.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the label.
     * Use ui.label to obtain the string value of the label.
    */
    get alignSubtitle(): (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void;
    set alignSubtitle(ev: (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void);
    private _alignHighlightLabel;
    private _alignHighlightLabel_wrapped;
    /**
     * Event which is raised when a highlight label of the gauge is aligned and styled.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the label.
     * Use ui.label to obtain the string value of the label.
    */
    get alignHighlightLabel(): (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void;
    set alignHighlightLabel(ev: (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void);
    private _formatTitle;
    private _formatTitle_wrapped;
    /**
     * Event which is raised when a title of the gauge is formatted.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the title will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the title.
     * Use ui.label to obtain the string value of the title.
    */
    get formatTitle(): (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void;
    set formatTitle(ev: (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void);
    private _formatSubtitle;
    private _formatSubtitle_wrapped;
    /**
     * Event which is raised when a subtitle of the gauge is formatted.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the subtitle will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the subtitle.
     * Use ui.label to obtain the string value of the subtitle.
    */
    get formatSubtitle(): (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void;
    set formatSubtitle(ev: (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void);
    private _formatHighlightLabel;
    private _formatHighlightLabel_wrapped;
    /**
     * Event which is raised when a highlight label of the gauge is formatted.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the title will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the title.
     * Use ui.label to obtain the string value of the title.
    */
    get formatHighlightLabel(): (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void;
    set formatHighlightLabel(ev: (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void);
    private _formatLabel;
    private _formatLabel_wrapped;
    /**
     * Event which is raised when a label of the gauge is formatted.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the label.
     * Use ui.label to obtain the string value of the label.
    */
    get formatLabel(): (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void;
    set formatLabel(ev: (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void);
    private _alignLabel;
    private _alignLabel_wrapped;
    /**
     * Event which is raised when a label of the gauge is aligned along the scale.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the label.
     * Use ui.label to obtain the string value of the label.
     * Use ui.width to obtain the width of the label.
     * Use ui.height to obtain the height of the label.
     * Use ui.offsetX to obtain the X offset of the label on the gauge scale.
     * Use ui.offsetY to obtain the Y offset of the label on the gauge scale.
    */
    get alignLabel(): (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void;
    set alignLabel(ev: (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void);
    private _valueChanged;
    private _valueChanged_wrapped;
    /**
     * Occurs when the Value property changes.
    */
    get valueChanged(): (s: IgrRadialGauge, e: IgrDoubleValueChangedEventArgs) => void;
    set valueChanged(ev: (s: IgrRadialGauge, e: IgrDoubleValueChangedEventArgs) => void);
    private _highlightValueChanged;
    private _highlightValueChanged_wrapped;
    /**
     * Occurs when the Hightlight Value property changes.
    */
    get highlightValueChanged(): (s: IgrRadialGauge, e: IgrDoubleValueChangedEventArgs) => void;
    set highlightValueChanged(ev: (s: IgrRadialGauge, e: IgrDoubleValueChangedEventArgs) => void);
    private _actualMinimumValueChange;
    private _actualMinimumValueChange_wrapped;
    get actualMinimumValueChange(): (s: IgrRadialGauge, e: number) => void;
    set actualMinimumValueChange(ev: (s: IgrRadialGauge, e: number) => void);
    private _actualMaximumValueChange;
    private _actualMaximumValueChange_wrapped;
    get actualMaximumValueChange(): (s: IgrRadialGauge, e: number) => void;
    set actualMaximumValueChange(ev: (s: IgrRadialGauge, e: number) => void);
}
export interface IIgrRadialGaugeProps {
    width?: string;
    height?: string;
    children?: React.ReactNode;
    /**
 * Gets or sets a collection of brushes to be used as the palette for gauge ranges.
*/
    rangeBrushes?: string[] | string;
    /**
     * Gets or sets a collection of brushes to be used as the palette for gauge outlines.
    */
    rangeOutlines?: string[] | string;
    /**
     * Gets or sets the minimum value of the scale.
    */
    minimumValue?: number | string;
    /**
     * Gets the resolved minimum value of the scale.
    */
    actualMinimumValue?: number | string;
    /**
     * Gets or sets the maximum value of the scale.
    */
    maximumValue?: number | string;
    /**
     * Gets the resolved maximum value of the scale.
    */
    actualMaximumValue?: number | string;
    /**
     * Gets or sets the interval to use for the scale.
    */
    interval?: number | string;
    /**
     * Gets or sets the x position of the center of the gauge with the value ranging from 0 to 1.
    */
    centerX?: number | string;
    /**
     * Gets or sets the y position of the center of the gauge with the value ranging from 0 to 1.
    */
    centerY?: number | string;
    /**
     * Gets or sets the value at which to point the needle of the gauge.
    */
    value?: number | string;
    /**
     * Gets or sets the highlight value at which to point the secondary needle of the gauge.
    */
    highlightValue?: number | string;
    /**
     * Gets the actual opacity of the primary needle while highlighting
    */
    actualHighlightValueOpacity?: number | string;
    /**
     * Gets or sets the opacity of the primary needle while highlighting
    */
    highlightValueOpacity?: number | string;
    /**
     * Gets whether and how to display the highlighted value.
    */
    actualHighlightValueDisplayMode?: HighlightedValueDisplayMode | string;
    /**
     * Gets or sets whether and how to display the highlighted value.
    */
    highlightValueDisplayMode?: HighlightedValueDisplayMode | string;
    /**
     * Gets or sets the start angle for the scale in degrees.
    */
    scaleStartAngle?: number | string;
    /**
     * Gets or sets the end angle for the scale in degrees.
    */
    scaleEndAngle?: number | string;
    /**
     * Gets or sets the direction in which the scale sweeps around the center from the start angle to end angle.
    */
    scaleSweepDirection?: SweepDirection | string;
    /**
     * Gets or sets the number of milliseconds over which changes to the gauge should be animated.
    */
    transitionDuration?: number | string;
    /**
     * Gets or sets the brush to use when rendering the fill of the needle.
    */
    needleBrush?: string;
    /**
     * Gets or sets the brush to use when rendering the outline of the needle.
    */
    needleOutline?: string;
    /**
     * Gets or sets the extent (from -1 to 1) at which to start rendering the needle, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    needleStartExtent?: number | string;
    /**
     * Gets or sets the extent (from -1 to 1) at which to end rendering the needle, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    needleEndExtent?: number | string;
    /**
     * Gets or sets the shape to use when rendering the needle from a number of options.
    */
    needleShape?: RadialGaugeNeedleShape | string;
    /**
     * Gets or sets the width of the needle at its point using a value from (0 to 1). Note: Only some needle shapes respect this property.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    needleStartWidthRatio?: number | string;
    /**
     * Gets or sets the width of the needle at its point using a value from (0 to 1). Note: Only some needle shapes respect this property.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    needleEndWidthRatio?: number | string;
    /**
     * Gets or sets the width of the needle at its feature which is closest to the base (e.g. a bulb) with a value from 0 to 1. Note: Only some needle shapes respect this property, namely: NeedleWithBulb, RectangleWithBulb, TrapezoidWithBulb, and TriangleWithBulb.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    needleBaseFeatureWidthRatio?: number | string;
    /**
     * Gets or sets the extent of the feature which is closest to the base (e.g. a bulb) with a value from -1 to 1. Note: Only some needle shapes respect this property, namely: NeedleWithBulb, RectangleWithBulb, TrapezoidWithBulb, and TriangleWithBulb.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    needleBaseFeatureExtent?: number | string;
    /**
     * Gets or sets the width of the needle at its feature which is closest to the point (e.g. the tapering point of a needle) with a value from 0 to 1. Note: Only some needle shapes respect this property.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    needlePointFeatureWidthRatio?: number | string;
    /**
     * Gets or sets the extent of the feature which is closest to the point (e.g. the tapering point of a needle) with a value from -1 to 1. Note: Only some needle shapes respect this property.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    needlePointFeatureExtent?: number | string;
    /**
     * Gets or sets the width of the cap of the needle with a value from 0 to 1. Note: Will only take effect if you have a cap set on the needle.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    needlePivotWidthRatio?: number | string;
    /**
     * Gets or sets the width of the inner cutout section of the needle cap with a value from 0 to 1. Note: Will only take effect if you have a cap set on the needle that has a cutout section.
    */
    needlePivotInnerWidthRatio?: number | string;
    /**
     * Gets or sets the shape to use for the needle cap.
    */
    needlePivotShape?: RadialGaugePivotShape | string;
    /**
     * Gets or sets the position at which to start rendering the scale, measured from the center of the gauge as a value from 0 to 1.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    scaleStartExtent?: number | string;
    /**
     * Gets or sets the brush to use for filling the needle cap. Note: this only applies to certain cap shapes.
    */
    needlePivotBrush?: string;
    /**
     * Gets or sets the brush to use for the outlines of the needle cap.
    */
    needlePivotOutline?: string;
    /**
     * Gets or sets the stroke thickness of the needle outline.
    */
    needleStrokeThickness?: number | string;
    /**
     * Gets or sets the stroke thickness to use for the outline of the needle cap.
    */
    needlePivotStrokeThickness?: number | string;
    /**
     * Gets or sets the position at which to stop rendering the scale as a value from 0 to 1 measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    scaleEndExtent?: number | string;
    /**
     * Gets or sets the position at which to put the labels as a value from 0 to 1, measured form the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    labelExtent?: number | string;
    /**
     * Gets or sets the interval to use for rendering labels. This defaults to be the same interval as the tickmarks on the scale.
    */
    labelInterval?: number | string;
    /**
     * Gets or sets the position at which to start rendering the major tickmarks as a value from 0 to 1, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    tickStartExtent?: number | string;
    /**
     * Gets or sets the position at which to stop rendering the major tickmarks as a value from 0 to 1, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    tickEndExtent?: number | string;
    /**
     * Gets or sets the stroke thickness to use when rendering ticks.
    */
    tickStrokeThickness?: number | string;
    /**
     * Gets or sets the brush to use for the major tickmarks.
    */
    tickBrush?: string;
    /**
     * Gets or sets the brush to use for the label font.
    */
    fontBrush?: string;
    /**
     * Gets or sets the position at which to start rendering the minor tickmarks as a value from 0 to 1, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    minorTickStartExtent?: number | string;
    /**
     * Gets or sets the position at which to stop rendering the minor tickmarks as a value from 0 to 1, measured from the center of the gauge.
     * Values further from zero than 1 can be used to make this extend further than the normal radius of the gauge.
    */
    minorTickEndExtent?: number | string;
    /**
     * Gets or sets the stroke thickness to use when rendering minor ticks.
    */
    minorTickStrokeThickness?: number | string;
    /**
     * Gets or sets the brush to use for the minor tickmarks.
    */
    minorTickBrush?: string;
    /**
     * Gets or sets the number of minor tickmarks to place between major tickmarks.
    */
    minorTickCount?: number | string;
    /**
     * Gets or sets the brush to use to fill the background of the scale.
    */
    scaleBrush?: string;
    /**
     * Gets or sets the brush to use to fill the backing of the gauge.
    */
    backingBrush?: string;
    /**
     * Gets or sets the brush to use for the outline of the backing.
    */
    backingOutline?: string;
    /**
     * Gets or sets the stroke thickness of the backing outline.
    */
    backingStrokeThickness?: number | string;
    /**
     * Gets or sets the outer extent of the gauge backing.
    */
    backingOuterExtent?: number | string;
    /**
     * Gets or sets the over sweep angle to apply to the backing if it is displaying fitted (in degrees). Must be greater or equal to 0.
    */
    backingOversweep?: number | string;
    /**
     * Gets or sets the extra degrees of sweep to apply to the scale background. Must be greater or equal to 0.
    */
    scaleOversweep?: number | string;
    /**
     * Gets or sets the oversweep shape to use for the excess fill area for the scale.
    */
    scaleOversweepShape?: RadialGaugeScaleOversweepShape | string;
    /**
     * Gets or sets the corner rounding radius to use for the fitted scale backings.
    */
    backingCornerRadius?: number | string;
    /**
     * Gets or sets the inner extent of the gauge backing.
    */
    backingInnerExtent?: number | string;
    /**
     * Gets or sets the type of shape to use for the backing of the gauge.
    */
    backingShape?: RadialGaugeBackingShape | string;
    /**
     * Gets or sets the multiplying factor to apply to the normal radius of the gauge.
     * The radius of the gauge is defined by the minimum of the width and height of the control divided by 2.0.
     * This introduces a multiplicative factor to that value.
    */
    radiusMultiplier?: number | string;
    /**
     * Gets or sets the strategy to use for omitting labels if the first and last label have the same value.
    */
    duplicateLabelOmissionStrategy?: RadialGaugeDuplicateLabelOmissionStrategy | string;
    /**
     * Gets or sets whether needle dragging is enabled or not.
    */
    isNeedleDraggingEnabled?: boolean | string;
    /**
     * Gets or sets whether the needle is constrained within the minimum and maximum value range during dragging.
    */
    isNeedleDraggingConstrained?: boolean | string;
    /**
     * Gets or sets whether needle dragging is enabled or not.
    */
    isHighlightNeedleDraggingEnabled?: boolean | string;
    /**
     * Gets or sets whether the needle is constrained within the minimum and maximum value range during dragging.
    */
    isHighlightNeedleDraggingConstrained?: boolean | string;
    /**
     * Gets or sets the font.
    */
    font?: string;
    /**
     * Gets or sets the label composite format used when creating label values.
    */
    labelFormat?: string;
    /**
     * Gets or sets the format specifiers to use with the LabelFormat string.
    */
    labelFormatSpecifiers?: any[];
    /**
     * Gets the transition progress of the animation when the control is animating.
    */
    transitionProgress?: number | string;
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    pixelScalingRatio?: number | string;
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    actualPixelScalingRatio?: number | string;
    /**
     * Gets the optical scaling ratio calculated by dividing minimum gauge size by value of OpticalScalingSize property.
    */
    opticalScalingRatio?: number | string;
    /**
     * Gets or sets the title uses optical scaling when the gauge is resized.
    */
    opticalScalingEnabled?: boolean | string;
    /**
     * Gets or sets the size at which labels have 100% optical scaling, e.g. labels will have larger fonts when gauge's size is larger
     * - labels will have 200% larger fonts when gauge's size is 1000 and this property is set to 500
     * - labels will have 50% smaller fonts when gauge's size is 250 and this property is set to 500
    */
    opticalScalingSize?: number | string;
    /**
     * Gets or sets the text displayed in the title of the gauge.
    */
    titleText?: string;
    /**
     * Gets or sets the text displayed in the subtitle of the gauge.
    */
    subtitleText?: string;
    /**
     * Gets or sets the angle for the inner label in degrees.
    */
    titleAngle?: number | string;
    /**
     * Gets or sets the angle for the inner label in degrees.
    */
    subtitleAngle?: number | string;
    /**
     * Gets or sets the angle for the inner label in degrees.
    */
    titleExtent?: number | string;
    /**
     * Gets or sets the angle for the inner label in degrees.
    */
    subtitleExtent?: number | string;
    /**
     * Gets or sets the brush to use for rendering inner unit text
    */
    titleBrush?: string;
    /**
     * Gets or sets the brush to use for rendering inner unit text
    */
    subtitleBrush?: string;
    /**
     * Gets or sets the title show values of the gauge.
    */
    titleDisplaysValue?: boolean | string;
    /**
     * Gets or sets the subtitle show values of the gauge.
    */
    subtitleDisplaysValue?: boolean | string;
    /**
     * Gets or sets whether or not the title should snap angle position to needle pivot (opposite of needle pointer).
    */
    titleSnapsToNeedlePivot?: boolean | string;
    /**
     * Gets or sets whether or not the subtitle should snap angle position to needle pivot (opposite of needle pointer).
    */
    subtitleSnapsToNeedlePivot?: boolean | string;
    /**
     * Gets or sets the subtitle format used when creating subtitle label.
    */
    subtitleFormat?: string;
    /**
     * Gets or sets the format specifiers to use with the SubtitleFormat string.
    */
    subtitleFormatSpecifiers?: any[];
    /**
     * Gets or sets the title format used when creating title label.
    */
    titleFormat?: string;
    /**
     * Gets or sets the format specifiers to use with the TitleFormat string.
    */
    titleFormatSpecifiers?: any[];
    /**
     * Gets or sets the text displayed for the highlight label of the gauge.
    */
    highlightLabelText?: string;
    /**
     * Gets or sets the angle for the highlight label in degrees.
    */
    highlightLabelAngle?: number | string;
    /**
     * Gets or sets the angle for the highlight label in degrees.
    */
    highlightLabelExtent?: number | string;
    /**
     * Gets or sets the brush to use for rendering highlight text
    */
    highlightLabelBrush?: string;
    /**
     * Gets or sets the highlight label shows values of the gauge.
    */
    highlightLabelDisplaysValue?: boolean | string;
    /**
     * Gets or sets whether or not the highlight label should snap angle position to needle pivot (opposite of needle pointer).
    */
    highlightLabelSnapsToNeedlePivot?: boolean | string;
    /**
     * Gets or sets the format used when creating highlight label.
    */
    highlightLabelFormat?: string;
    /**
     * Gets or sets the format specifiers to use with the HighlightLabelFormat string.
    */
    highlightLabelFormatSpecifiers?: any[];
    /**
     * Gets or Sets the style to use for the units text.
    */
    highlightLabelTextStyle?: string;
    /**
     * Gets or Sets the style to use for the units text.
    */
    subtitleTextStyle?: string;
    /**
     * Gets or Sets the style to use for the units text.
    */
    titleTextStyle?: string;
    /**
 * Event which is raised when a title of the gauge is aligned and styled.
 * Function takes first argument null and second argument ui.
 * Use ui.owner to obtain reference to gauge widget.
 * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
 * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
 * Use ui.startAngle to obtain the starting angle of gauge scale.
 * Use ui.endAngle to obtain the ending angle of gauge scale.
 * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
 * Use ui.value to obtain the value on the gauge scale associated with the label.
 * Use ui.label to obtain the string value of the label.
*/
    alignTitle?: (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void;
    /**
     * Event which is raised when a subtitle of the gauge is aligned and styled.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the label.
     * Use ui.label to obtain the string value of the label.
    */
    alignSubtitle?: (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void;
    /**
     * Event which is raised when a highlight label of the gauge is aligned and styled.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the label.
     * Use ui.label to obtain the string value of the label.
    */
    alignHighlightLabel?: (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void;
    /**
     * Event which is raised when a title of the gauge is formatted.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the title will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the title.
     * Use ui.label to obtain the string value of the title.
    */
    formatTitle?: (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void;
    /**
     * Event which is raised when a subtitle of the gauge is formatted.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the subtitle will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the subtitle.
     * Use ui.label to obtain the string value of the subtitle.
    */
    formatSubtitle?: (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void;
    /**
     * Event which is raised when a highlight label of the gauge is formatted.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the title will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the title.
     * Use ui.label to obtain the string value of the title.
    */
    formatHighlightLabel?: (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void;
    /**
     * Event which is raised when a label of the gauge is formatted.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the label.
     * Use ui.label to obtain the string value of the label.
    */
    formatLabel?: (s: IgrRadialGauge, e: IgrFormatRadialGaugeLabelEventArgs) => void;
    /**
     * Event which is raised when a label of the gauge is aligned along the scale.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to gauge widget.
     * Use ui.actualMinimumValue to obtain the minimum value of gauge scale.
     * Use ui.actualMaximumValue to obtain the maximum value of gauge scale.
     * Use ui.startAngle to obtain the starting angle of gauge scale.
     * Use ui.endAngle to obtain the ending angle of gauge scale.
     * Use ui.angle to obtain the angle on the gauge scale at which the label will be located.
     * Use ui.value to obtain the value on the gauge scale associated with the label.
     * Use ui.label to obtain the string value of the label.
     * Use ui.width to obtain the width of the label.
     * Use ui.height to obtain the height of the label.
     * Use ui.offsetX to obtain the X offset of the label on the gauge scale.
     * Use ui.offsetY to obtain the Y offset of the label on the gauge scale.
    */
    alignLabel?: (s: IgrRadialGauge, e: IgrAlignRadialGaugeLabelEventArgs) => void;
    /**
     * Occurs when the Value property changes.
    */
    valueChanged?: (s: IgrRadialGauge, e: IgrDoubleValueChangedEventArgs) => void;
    /**
     * Occurs when the Hightlight Value property changes.
    */
    highlightValueChanged?: (s: IgrRadialGauge, e: IgrDoubleValueChangedEventArgs) => void;
}
